@@ -6,7 +6,7 @@ package Amon2::Setup::Flavor::Large;
 use parent qw(Amon2::Setup::Flavor);
 use File::Path ();
 
-our $VERSION = '6.12';
+our $VERSION = '6.13';
 
 sub admin_script {
     my $self = shift;
@@ -92,6 +92,7 @@ sub run {
             'Amon2::Util'                        => 0,
             'Amon2::Web'                         => 0,
             'Amon2::Web::Dispatcher::RouterBoom' => 0,
+            'DBD::SQLite'                        => 0,
             'DBI'                                => 0,
             'File::ShareDir'                     => 0,
             'Getopt::Long'                       => 0,
@@ -104,6 +105,7 @@ sub run {
             'Plack::App::File'                   => 0,
             'Plack::Builder'                     => 0,
             'Plack::Loader'                      => 0,
+            'Plack::Middleware::ReverseProxy'    => 0,
             'Plack::Session::Store::DBI'         => 0,
             'Router::Boom'                       => '0.06',
             'Teng'                               => 0,
